==> react-ui-library-7.4.0.tgz: package/src/components/SearchInput.js <==
import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import SearchIcon from './SearchIcon'
import theme from './theme'
import splitProps from './utils/splitProps'
const { minorScale, majorScale, textColors, controlStateStyles } = theme

const styles = css({
  backgroundColor: controlStateStyles.default.backgroundColor,
  color: controlStateStyles.default.color,
  border: controlStateStyles.default.border,
  transition: controlStateStyles.default.transition,
  '&:focus': {
    border: controlStateStyles.focus.border,
    boxShadow: controlStateStyles.focus.boxShadow
  }
})

function useControlSizes ({ size, ...props }) {
  const sizes = theme.controlSizes[size]

  return {
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'small' ? minorScale(3) : majorScale(2),
    paddingLeft: size === 'small' ? majorScale(4) : minorScale(9),
    ...props
  }
}

const SearchInput = ({ className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(useControlSizes(props),
    /margin|width|height|display/gi)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      <SearchIcon
        style={{ pointerEvents: 'none' }}
        size='small'
        position='absolute'
        top='50%'
        marginLeft={props.size === 'small' ? minorScale(2) : minorScale(3)}
        marginTop={majorScale(-1)}
        fill={textColors.muted}
      />
      <Box is='input' className={cx(`${styles}`, className)} flex='1' rounded {...unmatchedProps} />
    </Box>
  )
}

SearchInput.propTypes = {
  ...Box.propTypes,
  size: PropTypes.oneOf(Object.keys(theme.controlSizes))
}

SearchInput.defaultProps = {
  size: 'default'
}

SearchInput.displayName = 'SearchInput'

export default SearchInput

==> react-ui-library-7.4.2.tgz: package/src/components/SearchInput.js <==
import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import SearchIcon from './SearchIcon'
import theme from './theme'
import splitProps from './utils/splitProps'
const { minorScale, majorScale, textColors, controlStateStyles } = theme

const styles = css({
  backgroundColor: controlStateStyles.default.backgroundColor,
  color: controlStateStyles.default.color,
  border: controlStateStyles.default.border,
  transition: controlStateStyles.default.transition,
  '&:focus': {
    border: controlStateStyles.focus.border,
    boxShadow: controlStateStyles.focus.boxShadow
  }
})

function useControlSizes ({ size, ...props }) {
  const sizes = theme.controlSizes[size]

  return {
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'small' ? minorScale(3) : majorScale(2),
    paddingLeft: size === 'small' ? majorScale(4) : minorScale(9),
    ...props
  }
}

const SearchInput = ({ className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(useControlSizes(props),
    /margin|width|height|display|flex|alignItems|justifyContent|flexDirection|flexGrow|flexShrink/gi)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      <SearchIcon
        style={{ pointerEvents: 'none' }}
        size='small'
        position='absolute'
        top='50%'
        marginLeft={props.size === 'small' ? minorScale(2) : minorScale(3)}
        marginTop={majorScale(-1)}
        fill={textColors.muted}
      />
      <Box is='input' className={cx(`${styles}`, className)} flex='1' rounded {...unmatchedProps} />
    </Box>
  )
}

SearchInput.propTypes = {
  ...Box.propTypes,
  size: PropTypes.oneOf(Object.keys(theme.controlSizes))
}

SearchInput.defaultProps = {
  size: 'default'
}

SearchInput.displayName = 'SearchInput'

export default SearchInput
